
UNDEFINED = -1


BCCOPY=0
BCENSURE=1
BCEXIST=2
BCNEW=3
BCINSERT=4


NOVAL="NOVALUE" #alternative None for functions which also accept NOne as valid input
                #but still want some params to be optional
